package info.textgrid.lab.collatex.model.equivalences;

import java.net.URI;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlTransient;

/**
 * A {@link Position} implementation that uses the index in the list of tokens
 * of a witness.
 */
@XmlSeeAlso(Position.class)
@XmlRootElement
public class TokenIndex extends Position {

	@Override
	public String toString() {
		return getUri().toString() + ":" + getIndex(); //$NON-NLS-1$
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = super.hashCode();
		result = prime * result + index;
		return result;
	}

	@Override
	public boolean equals(final Object obj) {
		if (this == obj)
			return true;
		if (!super.equals(obj))
			return false;
		if (getClass() != obj.getClass())
			return false;
		final TokenIndex other = (TokenIndex) obj;
		if (index != other.index)
			return false;
		return true;
	}

	@XmlTransient
	private int index;

	/**
	 * @return The number of the token in the list of tokens of a specific
	 *         witness. E.g., for the witness
	 * 
	 *         <pre>
	 * this is a test
	 * </pre>
	 * 
	 *         that is tokenized by whitespace, the token <code>is</code> would
	 *         have position 2.
	 */
	@XmlAttribute
	public int getIndex() {
		return index;
	}

	protected void setIndex(final int index) {
		this.index = index;
	}

	protected TokenIndex() {
	};

	public TokenIndex(final URI uri, final int index) {
		this.setUri(uri);
		this.setIndex(index);
	}


}
